<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="64"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>MX Welcome</source>
        <translation>Bienvenido a MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Salir de la aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>Acerca de esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation>¡Bienvenido!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation>Instalar MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Retocar (Panel, etc...)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manual del usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>FAQ (Preguntas frecuentes)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation>Paseo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Aplicaciones populares</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Foros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>REPORTE CORTO DEL SISTEMA:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="805"/>
        <source>DESKTOP</source>
        <translation>ESCRITORIO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="819"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Informe rápido del sistema (QSI) Reporte completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Terms of Use</source>
        <translation>Condiciones de uso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="846"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>El nombre &quot;MX Linux&quot; está cubierto por la Sublicencia de la Fundación Linux No. 20140605-0483. Desarrollamos software que está cubierto por una licencia libre que puede ser examinada en la lista Wiki. También incluimos software desarrollado por otros que está bajo una licencia libre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="856"/>
        <source>MX VERSION</source>
        <translation>VERSIÓN MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="863"/>
        <source>DEBIAN VERSION:</source>
        <translation>VERSIÓN DEBIAN:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="870"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>CON SOPORTE HASTA:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="890"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:10.5pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Show this dialog at start up</source>
        <translation>Mostrar esta ventana al inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>User demo, password:</source>
        <translation>Usuario demo, contraseña:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Superuser root, password:</source>
        <translation>Superusuario root, contraseña:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>About MX Welcome</source>
        <translation>Acerca de Bienvenido a MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Version: </source>
        <translation>Versión: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para mostrar una pantalla de bienvenida en MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licencia</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Registro de cambios</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Debe ejecutar este programa como usuario normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Esta herramienta muestra una pantalla de bienvenida con dos pestañas.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Comience con la pestaña &quot;Acerca de&quot; seleccionada. La pestaña &quot;Acerca de&quot; proporciona información básica sobre la versión actual de MX Linux, el hardware del usuario y el acceso a un informe completo del sistema.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Run a test mode.</source>
        <translation>Ejecutar un modo de prueba.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Debe ejecutar este programa como usuario normal.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>License</source>
        <translation type="unfinished">Licencia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <location filename="../about.cpp" line="50"/>
        <source>Changelog</source>
        <translation type="unfinished">Registro de cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Cerrar</translation>
    </message>
</context>
</TS>
